require_relative 'test_helper'

class AccountFetcherTest < Minitest::Test
  def test_raises_for_a_handle
    client = GrowViral::Keystore::Client.new(:development)
    assert_raises(GrowViral::HandleNotUidError) { client.fetch_account(213, "string") }
  end

  def test_response_is_correct
    application_id = 43
    uid = 1231212
    handle = "foobar"
    token = "asdasda"
    secret = "2349966adasds"

    output = {
      "application_id" => application_id,
      "handle" => handle,
      "uid" => uid,
      "token" => token,
      "secret" => secret
    }

    uri = URI.parse("http://localhost:3000/applications/#{application_id}/accounts/#{uid}")
    Net::HTTP.expects(:get_response).with(uri).returns(mock(code: '200', body: output.to_json))

    client = GrowViral::Keystore::Client.new(:development)
    account = client.fetch_account(application_id, uid)

    assert_equal application_id, account.application_id
    assert_equal uid, account.uid
    assert_equal handle, account.handle
    assert_equal token, account.token
    assert_equal secret, account.secret
  end

  def test_raises_if_404
    uid = 123
    application_id = 43
    uri = URI.parse("http://localhost:3000/applications/#{application_id}/accounts/#{uid}")
    Net::HTTP.expects(:get_response).with(uri).returns(mock(code: '404'))


    client = GrowViral::Keystore::Client.new(:development)
    assert_raises(GrowViral::NoAccountError) { client.fetch_account(application_id, uid) }
  end

  def test_exists_for_truth
    uid = 123
    application_id = 43
    uri = URI.parse("http://localhost:3000/applications/#{application_id}/accounts/#{uid}")
    Net::HTTP.expects(:get_response).with(uri).returns(mock(code: '200', body: {}.to_json))

    client = GrowViral::Keystore::Client.new(:development)
    assert client.account_exists?(application_id, uid)
  end

  def test_exists_for_false
    uid = 123
    application_id = 43
    uri = URI.parse("http://localhost:3000/applications/#{application_id}/accounts/#{uid}")
    Net::HTTP.expects(:get_response).with(uri).returns(mock(code: '404'))

    client = GrowViral::Keystore::Client.new(:development)
    refute client.account_exists?(application_id, uid)
  end

end
